==> ask-smapi-model-1.8.1.tar.gz: ask-smapi-model-1.8.1/ask_smapi_model/v1/skill/manifest/manifest_gadget_support.py <==
# coding: utf-8

#
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#

import pprint
import re  # noqa: F401
import six
import typing
from enum import Enum


if typing.TYPE_CHECKING:
    from typing import Dict, List, Optional, Union
    from datetime import datetime
    from ask_smapi_model.v1.skill.manifest.gadget_support import GadgetSupportV1


class ManifestGadgetSupport(object):
    """
    Defines the structure for gadget buttons support in the skill manifest.


    :param requirement: 
    :type requirement: (optional) ask_smapi_model.v1.skill.manifest.gadget_support.GadgetSupport
    :param min_gadget_buttons: Minimum number of gadget buttons required.
    :type min_gadget_buttons: (optional) int
    :param max_gadget_buttons: Maximum number of gadget buttons required.
    :type max_gadget_buttons: (optional) int
    :param num_players_max: Maximum number of players in the game.
    :type num_players_max: (optional) int
    :param num_players_min: Minimum number of players in the game.
    :type num_players_min: (optional) int

    """
    deserialized_types = {
        'requirement': 'ask_smapi_model.v1.skill.manifest.gadget_support.GadgetSupport',
        'min_gadget_buttons': 'int',
        'max_gadget_buttons': 'int',
        'num_players_max': 'int',
        'num_players_min': 'int'
    }  # type: Dict

    attribute_map = {
        'requirement': 'requirement',
        'min_gadget_buttons': 'minGadgetButtons',
        'max_gadget_buttons': 'maxGadgetButtons',
        'num_players_max': 'numPlayersMax',
        'num_players_min': 'numPlayersMin'
    }  # type: Dict
    supports_multiple_types = False

    def __init__(self, requirement=None, min_gadget_buttons=None, max_gadget_buttons=None, num_players_max=None, num_players_min=None):
        # type: (Optional[GadgetSupportV1], Optional[int], Optional[int], Optional[int], Optional[int]) -> None
        """Defines the structure for gadget buttons support in the skill manifest.

        :param requirement: 
        :type requirement: (optional) ask_smapi_model.v1.skill.manifest.gadget_support.GadgetSupport
        :param min_gadget_buttons: Minimum number of gadget buttons required.
        :type min_gadget_buttons: (optional) int
        :param max_gadget_buttons: Maximum number of gadget buttons required.
        :type max_gadget_buttons: (optional) int
        :param num_players_max: Maximum number of players in the game.
        :type num_players_max: (optional) int
        :param num_players_min: Minimum number of players in the game.
        :type num_players_min: (optional) int
        """
        self.__discriminator_value = None  # type: str

        self.requirement = requirement
        self.min_gadget_buttons = min_gadget_buttons
        self.max_gadget_buttons = max_gadget_buttons
        self.num_players_max = num_players_max
        self.num_players_min = num_players_min

    def to_dict(self):
        # type: () -> Dict[str, object]
        """Returns the model properties as a dict"""
        result = {}  # type: Dict

        for attr, _ in six.iteritems(self.deserialized_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else
                    x.value if isinstance(x, Enum) else x,
                    value
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else
                    (item[0], item[1].value)
                    if isinstance(item[1], Enum) else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        # type: () -> str
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        # type: () -> str
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are equal"""
        if not isinstance(other, ManifestGadgetSupport):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are not equal"""
        return not self == other

==> ask-smapi-model-1.19.0.tar.gz: ask-smapi-model-1.19.0/ask_smapi_model/v1/skill/manifest/manifest_gadget_support.py <==
# coding: utf-8

#
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#

import pprint
import re  # noqa: F401
import six
import typing
from enum import Enum


if typing.TYPE_CHECKING:
    from typing import Dict, List, Optional, Union, Any
    from datetime import datetime
    from ask_smapi_model.v1.skill.manifest.gadget_support_requirement import GadgetSupportRequirement as GadgetSupportRequirement_59434a55


class ManifestGadgetSupport(object):
    """
    Defines the structure for gadget buttons support in the skill manifest.


    :param requirement: 
    :type requirement: (optional) ask_smapi_model.v1.skill.manifest.gadget_support_requirement.GadgetSupportRequirement
    :param min_gadget_buttons: Minimum number of gadget buttons required.
    :type min_gadget_buttons: (optional) int
    :param max_gadget_buttons: Maximum number of gadget buttons required.
    :type max_gadget_buttons: (optional) int
    :param num_players_max: Maximum number of players in the game.
    :type num_players_max: (optional) int
    :param num_players_min: Minimum number of players in the game.
    :type num_players_min: (optional) int

    """
    deserialized_types = {
        'requirement': 'ask_smapi_model.v1.skill.manifest.gadget_support_requirement.GadgetSupportRequirement',
        'min_gadget_buttons': 'int',
        'max_gadget_buttons': 'int',
        'num_players_max': 'int',
        'num_players_min': 'int'
    }  # type: Dict

    attribute_map = {
        'requirement': 'requirement',
        'min_gadget_buttons': 'minGadgetButtons',
        'max_gadget_buttons': 'maxGadgetButtons',
        'num_players_max': 'numPlayersMax',
        'num_players_min': 'numPlayersMin'
    }  # type: Dict
    supports_multiple_types = False

    def __init__(self, requirement=None, min_gadget_buttons=None, max_gadget_buttons=None, num_players_max=None, num_players_min=None):
        # type: (Optional[GadgetSupportRequirement_59434a55], Optional[int], Optional[int], Optional[int], Optional[int]) -> None
        """Defines the structure for gadget buttons support in the skill manifest.

        :param requirement: 
        :type requirement: (optional) ask_smapi_model.v1.skill.manifest.gadget_support_requirement.GadgetSupportRequirement
        :param min_gadget_buttons: Minimum number of gadget buttons required.
        :type min_gadget_buttons: (optional) int
        :param max_gadget_buttons: Maximum number of gadget buttons required.
        :type max_gadget_buttons: (optional) int
        :param num_players_max: Maximum number of players in the game.
        :type num_players_max: (optional) int
        :param num_players_min: Minimum number of players in the game.
        :type num_players_min: (optional) int
        """
        self.__discriminator_value = None  # type: str

        self.requirement = requirement
        self.min_gadget_buttons = min_gadget_buttons
        self.max_gadget_buttons = max_gadget_buttons
        self.num_players_max = num_players_max
        self.num_players_min = num_players_min

    def to_dict(self):
        # type: () -> Dict[str, object]
        """Returns the model properties as a dict"""
        result = {}  # type: Dict

        for attr, _ in six.iteritems(self.deserialized_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else
                    x.value if isinstance(x, Enum) else x,
                    value
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else
                    (item[0], item[1].value)
                    if isinstance(item[1], Enum) else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        # type: () -> str
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        # type: () -> str
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are equal"""
        if not isinstance(other, ManifestGadgetSupport):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are not equal"""
        return not self == other
